@@ -12,6 +12,7 @@ from trexadmin.libs.http import create_rest_message
 from trexadmin.libs.http import StatusCode
 from trexmodel.models.datastore.pos_models import POSSetting
 from trexmodel.utils.model.model_util import create_db_client
+from trexmodel.models import merchant_helpers
 from trexmodel.models.datastore.product_models import ProductCatalogue,\
     ProductCategory
 from trexlib.utils.common.common_util import sort_list
@@ -63,8 +64,9 @@ def getPOSAccountSetting(activation_code):
                 with db_client.context():
                     #is_activated = POSSetting.activate(activation_code)
                     #if is_activated:
-                    
-                    pos_setting_details                                 = pos_setting.setting
+                    #merchant_acct                                       = pos_setting.merchant_acct_entity
+                    outlet                                              = pos_setting.assigned_outlet_entity
+                    pos_setting_details                                 = merchant_helpers.construct_setting_by_outlet(outlet, pos_setting=pos_setting) 
                     
                     pos_setting_details['logo_image_url']               = url_for('system_bp.merchant_logo_image_url', merchant_act_key=pos_setting_details.get('account_id'))
                 
@@ -111,9 +113,8 @@ def updateActivationAndGetPOSAccountSetting(activation_code, device_id):
                     pos_setting.activate(device_id)
             
                 if is_valid:    
-                    pos_setting_details                                 = pos_setting.setting
-                
-                    pos_setting_details['logo_image_url']               = url_for('system_bp.merchant_logo_image_url', merchant_act_key=pos_setting_details.get('account_id'))
+                    pos_setting_details                                 = merchant_helpers.construct_setting_by_outlet(pos_setting.assigned_outlet_entity, pos_setting=pos_setting)
+                    #pos_setting_details['logo_image_url']               = url_for('system_bp.merchant_logo_image_url', merchant_act_key=pos_setting_details.get('account_id'))
             
             if is_valid:
                 
@@ -399,10 +400,10 @@ def sales_overview_stat(merchant_code, outlet_key, transact_date):
             invoice = invoice_ref.to_dict()
             logger.debug('invoice=%s', invoice)
             
-            if invoice.get('is_void') == 1:
+            if invoice.get('status') == 'voided':
                 total_voided_count+=1
                 
-            elif invoice.get('is_paid') == 1:
+            elif invoice.get('status') == 'paid':
                 payment_details     = json.loads(invoice.get('payment_details'))
                 transaction_items   = json.loads(invoice.get('transaction_items'))
                 total_sales_amount+= payment_details.get('net_total_amount')
